@@ -200,11 +200,16 @@ static cpl_error_code amber_getCalibratorDiameter (const char * filename,
 	char              * tag=NULL;
 	char           *    tag_needed=NULL;
 	int                 calibNameDatabase_index=0;
+	cpl_frameset_iterator * it = NULL;
+
+	it = cpl_frameset_iterator_new(frameset);
+	cur_frame = cpl_frameset_iterator_get(it);
 
-	cur_frame = cpl_frameset_get_first(frameset);
 	if (cur_frame == NULL) {
 		cpl_msg_error(cpl_func, "No frame found in the SOF");
 		*error = 1;
+		cpl_frameset_iterator_delete(it);
+
 		/* Propagate error, if any */
 		return cpl_error_set(cpl_func, cpl_error_get_code());
 	}
@@ -215,6 +220,7 @@ static cpl_error_code amber_getCalibratorDiameter (const char * filename,
 	{
 		cpl_msg_warning(cpl_func,"Error loading the header of %s",filename);
 		*error=1;
+		cpl_frameset_iterator_delete(it);
 		/* Propagate error, if any */
 		return cpl_error_set(cpl_func, cpl_error_get_code());
 	}
@@ -229,6 +235,7 @@ static cpl_error_code amber_getCalibratorDiameter (const char * filename,
 	{
 		*error=1;
 		cpl_propertylist_delete(plist);
+		cpl_frameset_iterator_delete(it);
 		return cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
 				"Can not determine the Band from the header! ");
 	}
@@ -240,7 +247,8 @@ static cpl_error_code amber_getCalibratorDiameter (const char * filename,
 		/*      Check the right tags */
 		tag = (char*)cpl_frame_get_tag(cur_frame);
 		if (strcmp(tag, tag_needed)) {
-			cur_frame = cpl_frameset_get_next( frameset );
+		    cpl_frameset_iterator_advance(it, 1);
+		    cur_frame = cpl_frameset_iterator_get(it);
 			continue;
 		}
 		else{
@@ -249,6 +257,7 @@ static cpl_error_code amber_getCalibratorDiameter (const char * filename,
 			break;
 		}
 	}
+	cpl_frameset_iterator_delete(it);
 
 	if (strcmp(tag, tag_needed)) {
 		cpl_free(tag_needed);
@@ -978,6 +987,7 @@ static cpl_error_code amber_TransferFunctionCompute(
 	amdlibVIS3       vis3 = {NULL};
 	amdlibINS_CFG    insCfg;
 	amdlibSPECTRUM   spectrum={NULL};
+	cpl_frameset_iterator * it = NULL;
 
 	amdlibLogTrace("amdlibPerformSelection()");
 
@@ -1065,7 +1075,10 @@ static cpl_error_code amber_TransferFunctionCompute(
 	/*basename() may modify its argument, therefore I duplicate it*/
 
 	local_filename=cpl_sprintf("%s", filename);
-	local_frame = cpl_frameset_get_first(framelist);
+
+	it = cpl_frameset_iterator_new(framelist);
+	local_frame = cpl_frameset_iterator_get(it);
+
 	while(local_frame)
 	{
 		if(!strcmp(cpl_frame_get_filename(local_frame),filename))
@@ -1073,9 +1086,11 @@ static cpl_error_code amber_TransferFunctionCompute(
 			break;
 		}
 		else{
-			local_frame = cpl_frameset_get_next( framelist );
+		    cpl_frameset_iterator_advance(it, 1);
+		    local_frame = cpl_frameset_iterator_get(it);
 		}
 	}
+	cpl_frameset_iterator_delete(it);
 
 	cpl_msg_info(cpl_func,"Frame to inherit: %s",
 			cpl_frame_get_filename(local_frame));
